/* Include this file in your html if you are using the CSP mode. */

@charset "UTF-8";

[ng\:cloak], [ng-cloak], [data-ng-cloak], [x-ng-cloak],
.ng-cloak, .x-ng-cloak,
.ng-hide {
  display: none !important;
}

ng\:form {
  display: block;
}

/* The styles below ensure that the CSS transition will ALWAYS
 * animate and close. A nasty bug occurs with CSS transitions where
 * when the active class isn't set, or if the active class doesn't
 * contain any styles to transition to, then, if ngAnimate is used,
 * it will appear as if the webpage is broken due to the forever hanging
 * animations. The clip (!ie) and zoom (ie) CSS properties are used
 * since they trigger a transition without making the browser
 * animate anything and they're both highly underused CSS properties */
.ng-animate-start { clip:rect(0, auto, auto, 0); -ms-zoom:1.0001; }
.ng-animate-active { clip:rect(-1px, auto, auto, 0); -ms-zoom:1; }
